import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_apigateway._jsii
import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_wafv2._jsii
import aws_cdk.core._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/aws-wafwebacl-apigateway",
    "1.147.0",
    __name__[0:-6],
    "aws-wafwebacl-apigateway@1.147.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
